==> dokuwiki-2011.05.25a.tgz: dokuwiki/lib/plugins/usermanager/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Robert BOGENSCHNEIDER <robog@gmx.de>
 */
$lang['menu']                  = 'Administrado de Uzantoj';
$lang['noauth']                = '(identiĝo de uzantoj ne disponeblas)';
$lang['nosupport']             = '(administro de uzantoj ne estas subtenata)';
$lang['badauth']               = 'tiu identiĝa procezo ne validas';
$lang['user_id']               = 'Uzanto';
$lang['user_pass']             = 'Pasvorto';
$lang['user_name']             = 'Vera nomo';
$lang['user_mail']             = 'Retadreso';
$lang['user_groups']           = 'Grupoj';
$lang['field']                 = 'Kampo';
$lang['value']                 = 'Valoro';
$lang['add']                   = 'Aldoni';
$lang['delete']                = 'Forigi';
$lang['delete_selected']       = 'Forigi elektitan';
$lang['edit']                  = 'Modifi';
$lang['edit_prompt']           = 'Modifi tiun ĉi uzanton';
$lang['modify']                = 'Registri modifojn';
$lang['search']                = 'Serĉi';
$lang['search_prompt']         = 'Fari serĉon';
$lang['clear']                 = 'Refari serĉan filtron';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Montriĝas uzantoj %1$d-%2$d el %3$d trovitaj. %4$d uzantoj entute.';
$lang['nonefound']             = 'Neniu uzantoj troviĝas. %d uzantoj entute.';
$lang['delete_ok']             = '%d uzantoj estis forigitaj';
$lang['delete_fail']           = '%d malsukcesis esti forigitaj.';
$lang['update_ok']             = 'Tiu uzanto estis sukcese ĝisdatigita';
$lang['update_fail']           = 'Malsukceso okazis por ĝisdatigi tiun uzanton';
$lang['update_exists']         = 'Malsukceso okazis por ŝanĝi la nomon de tiu uzanto: la enmetita nomo (%s) jam ekzistas (ĉiuj aliaj ŝanĝoj estos aplikitaj)';
$lang['start']                 = 'Ekigi';
$lang['prev']                  = 'antaŭe';
$lang['next']                  = 'sekve';
$lang['last']                  = 'laste';
$lang['edit_usermissing']      = 'La elektita uzanto ne estis trovita: tiu nomo povis esti forigita aŭ ŝanĝita aliloke.';
$lang['user_notify']           = 'Avizi uzanton';
$lang['note_notify']           = 'Avizantaj mesaĝoj estos sendataj nur se la uzanto ekhavos novan pasvorton.';
$lang['note_group']            = 'Novaj uzantoj estos aldonitaj al la komuna grupo (%s) se neniu alia estos specifita.';
$lang['note_pass']             = 'La pasvorto estos aŭtomate kreita se la kampo estos lasita malplena kaj \'aviso al uzantoj\' estos ebligita.';
$lang['add_ok']                = 'La uzanto estis sukcese aldonita';
$lang['add_fail']              = 'Malsukceso okazis por aldoni uzulon';
$lang['notify_ok']             = 'Avizanta mesaĝo estis sendita';
$lang['notify_fail']           = 'La avizanta mesaĝo ne povis esti sendita';

==> dokuwiki-2012.01.25.tgz: dokuwiki/lib/plugins/usermanager/lang/eo/lang.php <==
<?php
/**
 * Esperantolanguage file
 *
 * @author Felipe Castro <fefcas@uol.com.br>
 * @author Felipe Castro <fefcas@gmail.com>
 * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
 * @author Felipo Kastro <fefcas@gmail.com>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Erik Pedersen <erik pedersen@shaw.ca>
 * @author Erik Pedersen <erik.pedersen@shaw.ca>
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Robert BOGENSCHNEIDER <robog@gmx.de>
 * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
 */
$lang['menu']                  = 'Administrado de uzantoj';
$lang['noauth']                = '(identiĝo de uzantoj ne disponeblas)';
$lang['nosupport']             = '(administro de uzantoj ne estas subtenata)';
$lang['badauth']               = 'tiu identiĝa procezo ne validas';
$lang['user_id']               = 'Uzanto';
$lang['user_pass']             = 'Pasvorto';
$lang['user_name']             = 'Vera nomo';
$lang['user_mail']             = 'Retadreso';
$lang['user_groups']           = 'Grupoj';
$lang['field']                 = 'Kampo';
$lang['value']                 = 'Valoro';
$lang['add']                   = 'Aldoni';
$lang['delete']                = 'Forigi';
$lang['delete_selected']       = 'Forigi elektitan';
$lang['edit']                  = 'Modifi';
$lang['edit_prompt']           = 'Modifi tiun ĉi uzanton';
$lang['modify']                = 'Registri modifojn';
$lang['search']                = 'Serĉi';
$lang['search_prompt']         = 'Fari serĉon';
$lang['clear']                 = 'Refari serĉan filtron';
$lang['filter']                = 'Filtro';
$lang['summary']               = 'Montriĝas uzantoj %1$d-%2$d el %3$d trovitaj. %4$d uzantoj entute.';
$lang['nonefound']             = 'Neniu uzantoj troviĝas. %d uzantoj entute.';
$lang['delete_ok']             = '%d uzantoj estis forigitaj';
$lang['delete_fail']           = '%d malsukcesis esti forigitaj.';
$lang['update_ok']             = 'Tiu uzanto estis sukcese ĝisdatigita';
$lang['update_fail']           = 'Malsukceso okazis por ĝisdatigi tiun uzanton';
$lang['update_exists']         = 'Malsukceso okazis por ŝanĝi la nomon de tiu uzanto: la enmetita nomo (%s) jam ekzistas (ĉiuj aliaj ŝanĝoj estos aplikitaj)';
$lang['start']                 = 'Ekigi';
$lang['prev']                  = 'antaŭe';
$lang['next']                  = 'sekve';
$lang['last']                  = 'laste';
$lang['edit_usermissing']      = 'La elektita uzanto ne estis trovita: tiu nomo povis esti forigita aŭ ŝanĝita aliloke.';
$lang['user_notify']           = 'Avizi uzanton';
$lang['note_notify']           = 'Avizantaj mesaĝoj estos sendataj nur se la uzanto ekhavos novan pasvorton.';
$lang['note_group']            = 'Novaj uzantoj estos aldonitaj al la komuna grupo (%s) se neniu alia estos specifita.';
$lang['note_pass']             = 'La pasvorto estos aŭtomate kreita se la kampo estos lasita malplena kaj \'aviso al uzantoj\' estos ebligita.';
$lang['add_ok']                = 'La uzanto estis sukcese aldonita';
$lang['add_fail']              = 'Malsukceso okazis por aldoni uzulon';
$lang['notify_ok']             = 'Avizanta mesaĝo estis sendita';
$lang['notify_fail']           = 'La avizanta mesaĝo ne povis esti sendita';
